DiplomatResult

Struct DiplomatResult 

#[repr(C)]
pub struct DiplomatResult<T, E> { value: DiplomatResultValue<T, E>, pub is_ok: bool, }
A Result-like type that can be passed across the FFI boundary as a value. Used internally to return Results and Options from functions.

Fields

value: DiplomatResultValue<T, E>is_ok: bool

Implementations

Source

impl<T, E> DiplomatResult<T, E>

pub fn as_ref(&self) -> Result<&T, &E>

Source

impl<T> DiplomatResult<T, ()>

pub fn into_option(self) -> Option<T>

Helper for converting into an Option to avoid trait ambiguity errors with Into

pub fn into_converted_option<U: From<T>>(self) -> Option<U>

Helper for converting into an Option with the inner type converted